<?php

namespace Drupal\domain_microsite;

use Drupal\Core\Security\TrustedCallbackInterface;

/**
 * Provides trusted callback for render alters.
 *
 * @see domain_microsite_contextual_links_view_alter().
 */
class DomainMicrositeContextualLinksViewAlter implements TrustedCallbackInterface {

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return ['postRender'];
  }

  /**
   * Replaces contextual link hrefs with microsite base_path appended.
   */
  public static function postRender($markup, array $element) {
    // base_path was passed into #contextual_links items, just get it from first item
    $base_url = $element['#contextual_links'][key($element['#contextual_links'])]['metadata']['base_url'];
    $markup = str_replace('href="', 'href="'.$base_url, $markup);
    return $markup;
  }

}
