<?php

namespace Drupal\domain_microsite;

use Drupal\Core\Render\BubbleableMetadata;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\PathProcessor\InboundPathProcessorInterface;
use Drupal\Core\PathProcessor\OutboundPathProcessorInterface;
use Drupal\domain\DomainNegotiatorInterface;
use Symfony\Component\HttpFoundation\Request;

class DomainMicrositePathProcessor implements OutboundPathProcessorInterface, InboundPathProcessorInterface {

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * @var \Drupal\domain\DomainNegotiatorInterface
   */
  protected $domainNegotiator;

  public function __construct(EntityTypeManagerInterface $entity_type_manager, DomainNegotiatorInterface $domain_negotiator) {
    $this->entityTypeManager = $entity_type_manager;
    $this->domainNegotiator = $domain_negotiator;
  }

  /**
   * {@inheritdoc}
   */
  public function processInbound($path, Request $request) {
    if($active = $this->domainNegotiator->getActiveDomain()) {
      if($base_path = $active->getThirdPartySetting('domain_microsite', 'base_path', '')) {
        $base_path_parts = explode('/', trim($base_path, '/'));
        $path_parts = explode('/', trim($path, '/'));
        if(count($path_parts) >= count($base_path_parts)) {
          // remove path parts from the front if they match base path parts
          foreach($base_path_parts as $i => $base_path_part) {
            if($path_parts[$i] == $base_path_part) {
              array_shift($path_parts);
            }
          }
          $path = '/'.implode('/', $path_parts);
        }
      }
    }
    return $path;
  }

  /**
   * {@inheritdoc}
   */
  public function processOutbound($path, &$options = array(), Request $request = NULL, BubbleableMetadata $bubbleable_metadata = NULL) {
    if($domain = $this->domainNegotiator->getActiveDomain()) {
      // let outbound accept $options['domain_id'] to load specific domain microsite
      if(!empty($options['domain_id']) && $new_domain = $this->entityTypeManager->getStorage('domain')->load($options['domain_id'])) {
        $domain = $new_domain;
      }
      if($base_path = $domain->getThirdPartySetting('domain_microsite', 'base_path')) {
        $path = $base_path . $path;
      }
    }
    if ($bubbleable_metadata) {
      $bubbleable_metadata->addCacheContexts(['domain_microsite']);
    }
    return $path;
  }

}
